@@ -151,41 +151,6 @@ int outlineCubicTo(const FT_Vector* control1, const FT_Vector* control2,
 }
 
 
-// Errors that may occur in loading font characters.
-// Here we just give warnings.
-void errorcode(FT_Error err)
-{
-    switch(err)
-    {
-        case 0x10:
-            Rf_warning("freetype: invalid glyph index");
-            break;
-        case 0x11:
-            Rf_warning("freetype: invalid character code");
-            break;
-        case 0x12:
-            Rf_warning("freetype: unsupported glyph image format");
-            break;
-        case 0x13:
-            Rf_warning("freetype: cannot render this glyph format");
-            break;
-        case 0x14:
-            Rf_warning("freetype: invalid outline");
-            break;
-        case 0x15:
-            Rf_warning("freetype: invalid composite glyph");
-            break;
-        case 0x16:
-            Rf_warning("freetype: too many hints");
-            break;
-        case 0x17:
-            Rf_warning("freetype: invalid pixel size");
-            break;
-        default:
-            Rf_warning("freetype: error code %d", err);
-            break;
-    }
-}
 
 SEXP showtextNewOutlineFuns()
 {
